# ogGui - OpenGnsys Administration Interface

## Introduction

Welcome to the new OpenGnsys administration interface. This manual will guide you through your first steps to configure and use the platform efficiently. The new web console represents a qualitative leap with the following main features

!!! info
    - Developed with Angular 18, a modern and up-to-date framework
    - Responsive web design that works on both desktop and mobile devices
    - Multilingual support with English translation

## System Access

To start using OpenGnsys

1. Open your preferred web browser
2. Enter the OpenGnsys server URL
3. On the login screen, enter your credentials (username and password)

Click on "Log In"

![oggui-login.png](../assets/images/screenshots/oggui-login.png)

## Main Interface

Once inside, you will find:

- **Sidebar navigation panel**: Access to all modules and functionalities
- **Top bar**: User information, notifications, and quick access to settings
- **Central workspace**: Where the selected information is displayed and managed

![OpenGnsys Web Console](../assets/images/screenshots/ogintro-webconsole.png)

## Initial Configuration

### User Management

User management allows you to control who has access to the system and what they can do.

![Configuration menu](../assets/images/screenshots/oggui-config_menu.png)

#### View Existing Users

Go to **Administration > Users** to see the list of current system users.

![User list](../assets/images/screenshots/oggui-config_usuarios.png)

#### Add a New User

1. On the Users page, click the "Add users" button
2. Complete the form with the following data:

![Add user](../assets/images/screenshots/oggui-administracion-usuarios-anadir_usuario.png)

- **Username**: Unique identifier for logging in
- **Password**: Access key (note: only administrators can change passwords)
- **Role**: Select one or more roles that will define the user's permissions
- **Organizational Unit**: Defines which classroom groups or machines the user can manage

3. Click "Save" to create the new user

#### Edit an Existing User

1. In the user list, locate the user you want to edit
2. Click the edit icon (pencil)
3. Update the necessary fields
4. Save the changes

#### Delete a User

1. In the user list, locate the user you want to delete
2. Click the delete icon (trash can)
3. Confirm the action when prompted

### Role Configuration

Roles define user permissions on the platform. OpenGnsys includes four predefined levels:

- **Super Administrator**: Full control of the platform, no restrictions
- **Organizational Unit Administrator**: Full control over the assigned organizational unit
- **Organizational Unit Operator**: Limited permissions to operate machines in the assigned unit
- **User**: Basic access to the platform

### Environment Variables

Environment variables define the connection configuration to the different components:

1. Go to **Administration > Environment Variables**
2. Configure the following variables according to your infrastructure:

- **OG_CORE_IP**: IP address of the main server
- **OG_DHCP_API_URL**: DHCP service API URL
- **OG_BOOT_API_URL**: Boot server API URL
- **OG_LOG_IP**: Logging server IP address
- **REMOTEPC_AUTH_LOGIN**: Authentication URL for RemotePC
- **REMOTEPC_AUTH_USERNAME**: Username for RemotePC
- **REMOTEPC_AUTH_PASSWORD**: Password for RemotePC
- **REMOTEPC_URL**: Base URL of the RemotePC service
- **SSL_ENABLED**: true or false

![oggui-administracion-env.png](../assets/images/screenshots/oggui-administracion-env.png)

!!! note "Note"
    UDS_ variables will appear as REMOTEPC_ in your installation

## Menu Navigation

The left sidebar contains all available menus based on your role and the active modules:

- **Groups**: Group management
- **Actions**: Actions, Commands, and Tasks management module
- **Subnets**: DHCP service management module
- **Boot**: Management module for ogLive and PXE boot services
- **Calendars**: Module to manage machine availability in the RemotePC service
- **Repositories**: Module to manage repositories and their associated images
- **Menus**: Allows managing the menus displayed when launching ogLive on a client machine

!!! note "Note"
    Some modules may not be available if they depend on external services that are not configured. For example, if the DHCP service is managed externally, accessing that menu will display a message indicating that the module is not enabled.

--8<-- "sections/oggui-grupos.md"
--8<-- "sections/oggui-acciones.md"
--8<-- "sections/oggui-cierre.md"
