## Hierarchical Containment Structure

The logical schema of OpenGnsys offers elements to organize computer equipment in a simplified hierarchical containment structure, as well as user control to access the schema or part of it.

The new hierarchical structure has been significantly simplified, now based on two main elements: **Organizational Units (Groups)** and **Clients (Workstations)**.

- **Organizational Units (Groups):**
Groups can be of any type according to organizational needs, allowing a completely flexible and adaptable structure for any organizational context.

- **Clients (Workstations):**
These represent the individual machines that will be managed by OpenGnsys.

This simplified structure enables greater organizational flexibility, conceptually adapting to any type of situation. For example, isolated workstations in different geographical locations can be efficiently grouped into a specific "client group," facilitating centralized management.

One of the main elements for organization remains the **organizational unit**. Its primary function is to group objects for administrative purposes and enable delegation of authority.

Delegation allows for the administration of a large number of centers, departments, or laboratories to be distributed among a group of administrator-type users who are trusted to perform specific administrative tasks.

### Scope of Application Concept

Each hierarchical element establishes a **scope of application**, a fundamental concept in infrastructure design. This scope determines the set of machines on which specific tasks can be executed, providing granular and organized control of management operations.

!!! tip "Infrastructure Design"
    The scope of application is key to efficiently planning the management of machines in your organization.

## Decentralized Administration

The OpenGnsys administration tool allows a single administrator to centrally manage resources. In addition to this centralized administration, a decentralized administration can be defined that leverages the new simplified hierarchical structure.

### Delegating Authority over an Organizational Unit

The console administrator or superadministrator can manage the delegation of administrative responsibilities for specific organizational units to other administrators.

With the new simplified structure, this delegation can be made over any type of group, providing greater flexibility in distributing administrative responsibilities.

These administrators will manage their organizational unit through the console's web interface, having full control over the elements contained within their scope of responsibility.

### Delegating Tasks to Users with or without Authority

An organizational unit administrator can delegate specific tasks within the scopes that belong to their organizational unit, regardless of the type of group they manage.

These delegated tasks are accessible by the user from the managed computer's own terminal. The delegated tasks are included in a menu that may require authentication – a private menu – or not – a public menu.

A **public menu** typically includes the task of starting a specific operating system. On the other hand, a **private menu** – which requires authentication – is intended to offer cloning options on the computer itself or on all computers in a specific group.

The flexibility of the new structure allows these delegations to adapt to various organizational scenarios, from traditional structures to geographically distributed groups.

## The Predefined OpenGnsys Schema

During the installation process of OpenGnsys, the schema is automatically configured, offering a basic structure adapted to the new simplified hierarchy. This default configuration implements the four conceptual types of Organizational Units to facilitate organizational management.

### Default Structure

The predefined schema establishes the following organizational hierarchy:

- **Center**: Represents the main organizational level
- **Classroom Group**: Allows grouping of multiple classrooms with similar characteristics
- **Classroom**: Defines specific physical spaces with computers
- **Client Group**: Facilitates the grouping of specific workstations

This default structure can be fully adapted to the specific needs of each organization, allowing nested groups at multiple levels according to particular requirements.

### Initial Administrative Configuration

Access to console administration is initially allowed for a single superadministrator user, who also has administrative rights over all organizational units by default. The name and password for this user are set during the installation process.

Delegated administration of organizational units is initially undefined, except for the OpenGnsys image repository service, which by default is the machine where the application is installed.

### Organizational Flexibility

Although this default structure is based on the traditional educational model (Center→Classroom Group→Classroom→Client Group), the new architecture allows surpassing this scheme, facilitating more complex or different organizations based on the specific needs of each environment.

This flexibility allows isolated workstations in different locations to be efficiently grouped or for completely different organizational structures from the traditional educational model to be implemented.

## Group Administration

To manage groups, access the **Groups** module from the left side menu, where the following screen will be displayed:

- Filter and Search Menu
- Group Tree (Organizational Unit/Classroom)
- Clients (corresponding to the selected group in the left panel)

![oggui-grupos.png](/assets/images/screenshots/oggui-grupos.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

## Group Features

Groups allow configuration inheritance, meaning settings applied to a higher-level group are automatically inherited by lower-level groups unless specified otherwise. This includes:

- Network and DHCP service
- Boot Server Configuration
  - ogLive version
  - PXE template
- NTP Server
- Image Repository
  - P2P Configuration (mode, time)
  - Multicast Configuration (speed, port, mode)
- Boot Menu
- Hardware Profile

### Creating Groups

To create a new group:

1. Go to the **Groups** menu
2. Select "New Organizational Unit"
3. Define the type of group (Center, Classroom Group, Classroom, Client Group)
4. Fill in the required information
5. Save the changes

![oggui-grupos_crear.png](/assets/images/screenshots/oggui-grupos_crear.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

### Creating Clients

To register clients, there are two options:

- Register a single client
- Bulk client registration

To register a client:

1. Go to the **Groups** menu
2. New Client -> Add Single Client
3. Fill in the client information

![oggui-grupos_crear-cliente.png](/assets/images/screenshots/oggui-grupos_crear-cliente.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

For bulk client registration:

- A text file must be created (it can be `.txt` or any plain text format) with the following DHCP configuration structure:
