# ogGui - Interfaz de Administración OpenGnsys

## Introducción

Bienvenido a la nueva interfaz de administración de OpenGnsys. Este manual te guiará en tus primeros pasos para configurar y utilizar eficientemente la plataforma. La nueva consola web representa un salto cualitativo con las siguientes características principales

!!! info
    - Desarrollada con Angular 18, un framework moderno y actual
    - Diseño web responsivo que funciona tanto en entornos de PC como en dispositivos móviles
    - Soporte multilingüe con traducción al inglés

Después de realizar este módulo podrá:

**Manejo de la interfaz**

- Describir la estructura jerárquica que proporciona OpenGnsys
- Gestionar usuarios y permisos
- Gestionar roles y autorización
- Configurar las variables de entorno

**Organización de los diferentes elementos**

- Gestión de Grupos y Clientes.
- Ámbito de aplicación. Acciones.

## Acceso al Sistema

Para comenzar a utilizar OpenGnsys

1. Abre tu navegador web preferido
2. Introduce la dirección URL del servidor OpenGnsys
3. En la pantalla de inicio de sesión, introduce tus credenciales (nombre de usuario y contraseña)

Haz clic en "Iniciar sesión"

![oggui-login.png](../assets/images/screenshots/oggui-login.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

## Interfaz Principal

Una vez dentro, encontrarás:

- **Panel de navegación lateral**: Acceso a todos los módulos y funcionalidades
- **Barra superior**: Información del usuario, notificaciones y acceso rápido a configuraciones
- **Área de trabajo central**: Donde se visualiza y gestiona la información seleccionada

![Consola Web OpenGnsys](../assets/images/screenshots/ogintro-webconsole.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

## Configuración Inicial

### Gestión de Usuarios

La gestión de usuarios te permite controlar quién tiene acceso al sistema y qué puede hacer.

![Menú de configuración](../assets/images/screenshots/oggui-config_menu.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

#### Visualizar Usuarios Existentes

Accede al menú **Administración > Usuarios** para ver la lista de usuarios actuales del sistema.

![Lista de usuarios](../assets/images/screenshots/oggui-config_usuarios.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

#### Añadir un Nuevo Usuario

1. En la pantalla de usuarios, haz clic en el botón "Añadir Usuarios"
2. Completa el formulario con los siguientes datos:

![Añadir usuario](../assets/images/screenshots/oggui-administracion-usuarios-anadir_usuario.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

- **Nombre de Usuario**: Identificador único para iniciar sesión
- **Contraseña**: Clave de acceso (nota: solo los administradores pueden cambiar contraseñas)
- **Rol**: Selecciona uno o varios roles que definirán los permisos del usuario
- **Unidad Organizativa**: Define sobre qué grupos de aulas o equipos podrá administrar el usuario

3. Haz clic en "Guardar" para crear el nuevo usuario

#### Editar un Usuario Existente

1. En la lista de usuarios, localiza el usuario que deseas modificar
2. Haz clic en el icono de edición (lápiz)
3. Actualiza los campos necesarios
4. Guarda los cambios

#### Eliminar un Usuario

1. En la lista de usuarios, localiza el usuario que deseas eliminar
2. Haz clic en el icono de eliminación (papelera)
3. Confirma la acción cuando se te solicite

### Configuración de Roles

Los roles definen los permisos de los usuarios en la plataforma. OpenGnsys incluye cuatro niveles predefinidos:

- **Super Admin**: Control total de la plataforma, sin restricciones
- **Admin de Unidad Organizativa**: Control completo sobre la unidad organizativa asignada
- **Operador de Unidad Organizativa**: Permisos limitados para operar equipos en la unidad asignada
- **Usuario**: Acceso básico a la plataforma

### Variables de Entorno

Las variables de entorno definen la configuración de conexión con los diferentes componentes:

1. Accede a **Administración > Variables de Entorno**
2. Configura las siguientes variables según tu infraestructura:

- **OG_CORE_IP**: Dirección IP del servidor principal
- **OG_DHCP_API_URL**: URL de la API del servicio DHCP
- **OG_BOOT_API_URL**: URL de la API del servidor de arranque
- **OG_LOG_IP**: Dirección IP del servidor de logs
- **REMOTEPC_AUTH_LOGIN**: URL de autenticación para RemotePC
- **REMOTEPC_AUTH_USERNAME**: Usuario para RemotePC
- **REMOTEPC_AUTH_PASSWORD**: Contraseña para RemotePC
- **REMOTEPC_URL**: URL base del servicio RemotePC
- **SSL_ENABLED**: verdadero o falso.

![oggui-administracion-env.png](../assets/images/screenshots/oggui-administracion-env.png){ style="display: block; margin: 20px auto; max-width: min(1024px, 100%); height: auto;" }

!!! note "Nota"
    Las variables UDS_ aparecerán como REMOTEPC_ en tu instalación

## Navegación por los Menús

El panel lateral izquierdo contiene todos los menús disponibles según tu rol y los módulos activos:

- **Grupos**: Administración de los grupos
- **Acciones**: El módulo de gestión de Acciones, Comandos y Tareas.
- **Subredes**: El módulo de gestión del servicio de DHCP.
- **Boot**: El módulo de gestión de los servicios de arranque ogLive y PXE.
- **Calendarios**: Módulo para la gestión de disponibilidad de equipos en el servicio RemotePC
- **Repositorios**: Módulo para la gestión de repositorios y las imágenes asociadas a cada uno.
- **Menús**: Permite administrar los menús que se mostarán al iniciar ogLive en un equipo cliente.

!!! note "Nota"
    Es posible que algunos módulos no estén disponibles si dependen de servicios externos no configurados. Por ejemplo, si el servicio DHCP se gestiona externamente, al acceder a dicho menú se mostrará un aviso indicando que el módulo no está habilitado.

--8<-- "sections/oggui-grupos.md"
--8<-- "sections/oggui-acciones.md"
--8<-- "sections/oggui-cierre.md"
